# frozen_string_literal: true

require 'open3'
require_relative '../../datatypes/integer'
require_relative '../initsystem'

module Cfgd
  class Adapter
    # Initsystem class for systemd based systems
    class Systemd < AbstractInitsystem
      def self.supports_os?(os)
        true if %w[debian archlinux].include? os
      end

      SYSTEMCTL_BIN = 'systemctl'
      SYSTEMCTL_START_ARGS = 'start'
      SYSTEMCTL_STOP_ARGS = 'stop'
      SYSTEMCTL_RESTART_ARGS = 'restart'
      SYSTEMCTL_STATUS_ARGS = 'status'
      SHELL_ENV = 'LANG=C'
      def self.start(name)
        cmd = "#{SHELL_ENV} #{SYSTEMCTL_BIN} #{SYSTEMCTL_START_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.stop(name)
        cmd = "#{SHELL_ENV} #{SYSTEMCTL_BIN} #{SYSTEMCTL_STOP_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.restart(name)
        cmd = "#{SHELL_ENV} #{SYSTEMCTL_BIN} #{SYSTEMCTL_RESTART_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.status(name)
        cmd = "#{SHELL_ENV} #{SYSTEMCTL_BIN} #{SYSTEMCTL_STATUS_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end
    end
  end
end
