# frozen_string_literal: true

require 'open3'
require_relative '../../datatypes/integer'
require_relative '../initsystem'

module Cfgd
  class Adapter
    # Initsystem class for systemd based systems
    class Sysvinit < AbstractInitsystem
      def self.supports_os?(os)
        true if ['freebsd'].include? os
      end

      SERVICE_BIN = 'service'
      SERVICE_START_ARGS = 'start'
      SERVICE_STOP_ARGS = 'stop'
      SERVICE_RESTART_ARGS = 'restart'
      SERVICE_STATUS_ARGS = 'status'
      SHELL_ENV = 'LANG=C'
      def self.start(name)
        cmd = "#{SHELL_ENV} #{SERVICE_BIN} #{name} #{SERVICE_START_ARGS}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.stop(name)
        cmd = "#{SHELL_ENV} #{SERVICE_BIN} #{name} #{SERVICE_STOP_ARGS}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.restart(name)
        cmd = "#{SHELL_ENV} #{SERVICE_BIN} #{name} #{SERVICE_RESTART_ARGS}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.status(name)
        cmd = "#{SHELL_ENV} #{SERVICE_BIN} #{name} #{SERVICE_STATUS_ARGS}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end
    end
  end
end
