# frozen_string_literal: true

require 'open3'
require_relative '../../datatypes/integer'
require_relative '../pkgmanager'

module Cfgd
  class Adapter
    # Pkgmanager class for debian
    class APT < AbstractPkgmanager
      def self.supports_os?(os)
        true if os.eql? 'debian'
      end

      APT_BIN = '/usr/bin/apt'
      DPKG_BIN = '/usr/bin/dpkg'
      APT_ARGS = '-y'
      APT_INSTALL_ARGS = 'install'
      APT_UPDATE_ARGS = 'update'
      APT_UPGRADE_ARGS = 'upgrade'
      APT_REMOVE_ARGS = 'purge'
      DPKG_INFO_ARGS = '-s'
      SHELL_ENV = 'LANG=C'
      def self.install_single(name)
        cmd = "#{SHELL_ENV} #{APT_BIN} #{APT_INSTALL_ARGS} #{APT_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.installed?(name)
        cmd = "#{SHELL_ENV} #{DPKG_BIN} #{DPKG_INFO_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.remove_single(name)
        cmd = "#{SHELL_ENV} #{APT_BIN} #{APT_REMOVE_ARGS} #{APT_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end
    end
  end
end
