# frozen_string_literal: true

require 'open3'
require_relative '../../datatypes/integer'
require_relative '../pkgmanager'

module Cfgd
  class Adapter
    # Pkgmanager class for archlinux
    class PACMAN < AbstractPkgmanager
      def self.supports_os?(os)
        true if os.eql? 'archlinux'
      end

      PACMAN_BIN = '/usr/bin/pacman'
      PACMAN_ARGS = '--noconfirm'
      PACMAN_INSTALL_ARGS = '-S'
      PACMAN_INFO_ARGS = '-Qi'
      PACMAN_UPDATE_ARGS = '-Sy'
      PACMAN_UPGRADE_ARGS = '-Syyu'
      PACMAN_REMOVE_ARGS = '-Rsscn'
      SHELL_ENV = 'LANG=C'
      def self.install_single(name)
        cmd = "#{SHELL_ENV} #{PACMAN_BIN} #{PACMAN_INSTALL_ARGS} #{PACMAN_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.installed?(name)
        cmd = "#{SHELL_ENV} #{PACMAN_BIN} #{PACMAN_INFO_ARGS} #{PACMAN_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.remove_single(name)
        cmd = "#{SHELL_ENV} #{PACMAN_BIN} #{PACMAN_REMOVE_ARGS} #{PACMAN_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end
    end
  end
end
