# frozen_string_literal: true

require 'open3'
require_relative '../pkgmanager'
require_relative '../../datatypes/integer'

module Cfgd
  class Adapter
    # Pkgmanager class for freebsd
    class PKG < AbstractPkgmanager
      def self.supports_os?(os)
        true if os.eql? 'freebsd'
      end

      PKG_BIN = '/usr/sbin/pkg'
      PKG_ARGS = '--yes'
      PKG_INSTALL_ARGS = 'install'
      PKG_INFO_ARGS = 'info'
      PKG_UPDATE_ARGS = 'update'
      PKG_UPGRADE_ARGS = 'upgrade'
      PKG_REMOVE_ARGS = 'remove'
      SHELL_ENV = 'LANG=C'
      def self.install_single(name)
        cmd = "#{SHELL_ENV} #{PKG_BIN} #{PKG_INSTALL_ARGS} #{PKG_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.installed?(name)
        cmd = "#{SHELL_ENV} #{PKG_BIN} #{PKG_INFO_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end

      def self.remove_single(name)
        cmd = "#{SHELL_ENV} #{PKG_BIN} #{PKG_REMOVE_ARGS} #{PKG_ARGS} #{name}"
        _stdout, _stderr, status = Open3.capture3(cmd)
        status.exitstatus.shellexit
      end
    end
  end
end
