# frozen_string_literal: true

require 'fileutils'
require 'erb'
require 'open-uri'

require_relative './exceptions'

module Cfgd
  # provides some basic file operations
  class Files < Guide
    # self.create
    # parent method for file creation
    #
    def self.create(path)
      args = yield if block_given?
      raise ArgumentError, 'No arguments given' until block_given?

      # use path from args if given
      path = args[:path] until path.eql? args[:path]
      if Enum.new('template').check(args[:type])
        template = args[:source]
        type = args[:type]
        debug "#{name}.#{__method__} => #{path}"
        begin
          send(type, template, path, args)
          true
        rescue StandardError
          false
        end
      else
        raise ArgumentError, 'Give a valid type' until block_given?
      end
    end

    # self.download
    # download a file via http/https
    #
    def self.download(path)
      args = yield if block_given?
      raise ArgumentError, 'No arguments given' until block_given?
      source = args[:source]
      path = args[:path] until path.eql? args[:path]
      debug "#{name}.#{__method__} => #{path}"
      begin
        tempfile = URI.parse(source).open
        tempfile.close
        FileUtils.mv tempfile.path, path
        true
      rescue StandardError
        false
      end
    end

    # self.remove
    # parent method for file deletion
    #
    def self.remove(path)
      if block_given?
        args = yield
        path = args[:path] until path.eql? args[:path]
      end
      debug "#{name}.#{__method__} => #{path}"
      begin
        File.delete(path) if File.exist?(path)
        true
      rescue StandardError
        false
        # raise FileNotFound, path
      end
    end

    # self.link
    # parent method for file linking
    #
    def self.link(destination)
      args = yield if block_given?
      raise ArgumentError, 'No arguments given' until block_given?
      exit 1 until defined?(args)
      destination = args[:destination] until destination.eql? args[:destination]
      if Enum.new('soft', 'hard').check(args[:type])
        type = args[:type]
        source = args[:source]
        debug "#{name}.#{__method__} => #{source} to #{destination}"
        begin
          send(type, source, destination)
          true
        rescue StandardError
          false
        end
      else
        raise ArgumentError, 'Give a valid type' until block_given?
      end
    end

    private_class_method def self.hard(source, destination)
      FileUtils.ln(source, destination)
    end

    private_class_method def self.soft(source, destination)
      FileUtils.ln_s(source, destination)
    end

    private_class_method def self.template(template, path, args)
      if File.file?(template)
        File.open(path, 'w') do |fo|
          begin
            fo.puts ERB.new(File.read(template)).result(binding)
            true
          rescue StandardError
            false
          end
        end
      else
        warn "File not found: #{template}"
        false
      end
    end
  end
end
