# frozen_string_literal: true

require 'optparse'

module Cfgd
  # Simple user interface for cfgd
  class UI
    def initialize
      set_default_options
      parse_options
      start_cfgd
    end

    protected

    def start_cfgd
      require @opts[:config]
    end

    def set_default_options
      @opts = {
        config: '/etc/cfgd.rb',
        debug: false
      }
    end

    def parse_options
      OptionParser.new do |opts|
        opts.banner = 'Usage: cfgd [options]'
        opts.on('-c', '--config FILE', 'Config file to use') do |file|
          if File.exist?(file)
            @opts[:config] = file
          else
            die("Config file #{file} does not exist")
          end
        end
        opts.on('-d', '--debug', 'Verbose/Debug mode') do
          @opts[:debug] = true
        end
      end.parse!
    end

    def die(msg)
      warn(msg)
      exit 1
    end
  end
end
